@@ -117,7 +117,8 @@ class FS(object):
         :param permissions: :class:`~fs.permissions.Permissions`
             instance.
         :type permissions: Permissions
-        :param bool recreate: Do not raise an error if the directory exists.
+        :param bool recreate: Do not raise an error if the directory
+            exists.
         :rtype: :class:`~fs.subfs.SubFS`
 
         :raises fs.errors.DirectoryExists: if the path already exists.
@@ -191,8 +192,8 @@ class FS(object):
         :raises fs.errors.ResourceNotFound: If `path` does not exist
             on the filesystem.
 
-        This method is the compliment to :class:`~fs.base.getinfo` and is
-        used to set info values on a resource.
+        This method is the compliment to :class:`~fs.base.getinfo` and
+        is used to set info values on a resource.
 
         The ``info`` dict should be in the same format as the raw
         info returned by ``getinfo(file).raw``. Here's an example::
@@ -707,6 +708,17 @@ class FS(object):
         except errors.ResourceNotFound:
             return False
 
+    def islink(self, path):
+        """
+        Check if a path is a symlink.
+
+        :param str path: A path on the filesystem.
+        :rtype: bool
+
+        """
+        self.getinfo(path)
+        return False
+
     def lock(self):
         """
         Get a context manager that *locks* the filesystem.
@@ -727,7 +739,7 @@ class FS(object):
         multiple filesystem methods. Individual methods are thread safe
         already, and don't need to be locked.
 
-        ..note ::
+        .. note::
             This only locks at the Python level. There is nothing to
             prevent other processes from modifying the filesystem
             outside of the filesystem instance.
@@ -846,8 +858,7 @@ class FS(object):
             ``utf-8``)
         :param str errors: What to do with unicode decode errors (see
             `stdlib docs <https://docs.python.org/3/library/codecs.html#error-handlers>`_)
-        :param str newline: New line parameter (See `stdlib docs
-            <https://docs.python.org/3/library/functions.html#open>`_)
+        :param str newline: New line parameter (See stdlib docs).
         :param options: Additional keyword parameters to set
             implementation specific options (if required). See
             implementation docs for details.
